@@ -181,6 +181,18 @@ public class XmlResource extends AbstractResource
     return baseNode_ ;
   }
 
+  /**
+   * vf̖O擾B
+   * <br>
+   * vfɖOԂ܂܂Ăꍇ́A[JԂB
+   *
+   * @return vf̖OB
+   */
+  public String getBaseElementName()
+  {
+    return getBaseNode().getLocalName();
+  }
+
   /**
    * w肳ꂽL[ɍŏɊYm[h擾B
    * <br>
@@ -233,7 +245,7 @@ public class XmlResource extends AbstractResource
 
       // for namespace support.
       //if (! n.getNodeName().equals(elemName)) {
-      if (! elemName.equals(n.getLocalName())) {
+      if (! elemName.equals("*") && ! elemName.equals(n.getLocalName())) {
         continue;
       }
 
@@ -315,7 +327,7 @@ public class XmlResource extends AbstractResource
 
       // for namespace support.
       //if (! n.getNodeName().equals(elemName)) {
-      if (! elemName.equals(n.getLocalName())) {
+      if (! elemName.equals("*") && ! elemName.equals(n.getLocalName())) {
         continue;
       }
 
@@ -708,6 +720,37 @@ public class XmlResource extends AbstractResource
     }
   }
 
+  /**
+   * ݂̊vf̑SẴeLXglƁAqvf̃\[XEIuWFNgi[
+   * Xg擾B
+   *
+   * @return ݂̊vf̃eLXglAyюqvf̃\[XEIuWFNg
+   *         i[XgB
+   */
+  public synchronized List<Object> getValuesAndChildren()
+  {
+    List<Object> lst = new LinkedList<Object>();
+    Node base = getBaseNode();
+    for (Node n = base.getFirstChild(); n != null; n = n.getNextSibling()) {
+      switch (n.getNodeType()) {
+      case Node.ELEMENT_NODE :
+        XmlResource res = new XmlResource(this);
+        res.baseNode_ = n;
+        lst.add(res);
+        break;
+      case Node.CDATA_SECTION_NODE :
+        lst.add(n.getNodeValue());
+        break;
+      case Node.TEXT_NODE :
+        String s = n.getNodeValue().trim();
+        if (s.length() == 0) continue;
+        lst.add(shortenWhitespace(s));
+        break;
+      }
+    }
+    return lst;
+  }
+
   /**
    * ̃IuWFNgďB
    */
